@@ -13,12 +13,12 @@
 #ifndef PRIMECOUNT_H
 #define PRIMECOUNT_H
 
-#include <stddef.h>
+#include <stdbool.h>
 #include <stdint.h>
 
-#define PRIMECOUNT_VERSION "7.19"
-#define PRIMECOUNT_VERSION_MAJOR 7
-#define PRIMECOUNT_VERSION_MINOR 19
+#define PRIMECOUNT_VERSION "8.2"
+#define PRIMECOUNT_VERSION_MAJOR 8
+#define PRIMECOUNT_VERSION_MINOR 2
 
 #ifdef __cplusplus
 extern "C" {
@@ -55,8 +55,12 @@ int64_t primecount_pi(int64_t x);
  * Count the number of primes <= x using Xavier Gourdon's
  * algorithm. Uses all CPU cores by default.
  * 
- * @pre     x <= primecount_get_max_x() which is 10^31 on 64-bit
- *          systems and 2^63-1 on 32-bit systems.
+ * The 128-bit API automatically falls back to the 64-bit
+ * implementation for x <= 2^63−1. Therefore, there is no
+ * performance penalty for using only the 128-bit API.
+ * 
+ * @pre     x <= 10^31 on 64-bit systems and
+ *          x <= 2^63-1 on 32-bit systems.
  * @return  -1 if an error occurs, else the number of primes <= x.
  * 
  * Run time: O(x^(2/3) / (log x)^2)
@@ -64,34 +68,6 @@ int64_t primecount_pi(int64_t x);
  */
 pc_int128_t primecount_pi_128(pc_int128_t x);
 
-/*
- * 128-bit prime counting function.
- * Count the number of primes <= x using Xavier Gourdon's
- * algorithm. Uses all CPU cores by default.
- * 
- * @param x    Null-terminated string integer e.g. "12345".
- *             Note that x must be <= primecount_get_max_x() which is
- *             10^31 on 64-bit systems and 2^63-1 on 32-bit systems.
- * @param res  Result output buffer.
- * @param len  Length of the res buffer. The length must be sufficiently
- *             large to fit the result, 32 is always enough.
- * @return     Returns -1 if an error occurs, else returns the number
- *             of characters (>= 1) that have been written to the
- *             res buffer, not counting the terminating null character.
- * 
- * Run time: O(x^(2/3) / (log x)^2)
- * Memory usage: O(x^(1/3) * (log x)^3)
- */
-int primecount_pi_str(const char* x, char* res, size_t len);
-
-/*
- * Partial sieve function (a.k.a. Legendre-sum).
- * phi(x, a) counts the numbers <= x that are not divisible
- * by any of the first a primes.
- * @return -1 if an error occurs.
- */
-int64_t primecount_phi(int64_t x, int64_t a);
-
 /*
  * Find the nth prime using a combination of the prime counting
  * function and the sieve of Eratosthenes.
@@ -109,6 +85,10 @@ int64_t primecount_nth_prime(int64_t n);
  * Find the nth prime using a combination of the prime counting
  * function and the sieve of Eratosthenes.
  * 
+ * The 128-bit API automatically falls back to the 64-bit
+ * implementation when appropriate. Therefore, there is
+ * no performance penalty for using only the 128-bit API.
+ * 
  * @pre     n <= 10^29 on 64-bit systems and
  *          n <= 216289611853439384 on 32-bit systems.
  * @return  -1 if an error occurs, else the nth prime.
@@ -119,13 +99,12 @@ int64_t primecount_nth_prime(int64_t n);
 pc_int128_t primecount_nth_prime_128(pc_int128_t n);
 
 /*
- * Largest number supported by primecount_pi_str(x).
- * @return 64-bit CPUs: 10^31,
- *         32-bit CPUs: 2^63-1
- * The return type is a char* as primecount_get_max_x() may be a
- * 128-bit integer which is not supported by some compilers.
+ * Partial sieve function (a.k.a. Legendre-sum).
+ * phi(x, a) counts the numbers <= x that are not divisible
+ * by any of the first a primes.
+ * @return -1 if an error occurs.
  */
-const char* primecount_get_max_x(void);
+int64_t primecount_phi(int64_t x, int64_t a);
 
 /*  Get the currently set number of threads */
 int primecount_get_num_threads(void);
@@ -133,6 +112,15 @@ int primecount_get_num_threads(void);
 /*  Set the number of threads */
 void primecount_set_num_threads(int num_threads);
 
+/*
+ * Recompute pi(x) with alternative alpha tuning factor(s) to
+ * verify the first result. This redundancy helps guard 
+ * against potential bugs in primecount: if an error exists,
+ * it is highly unlikely that both pi(x) computations would
+ * produce the same (incorrect) result.
+ */
+void primecount_set_double_check(bool enable);
+
 /* Get the primecount version number, in the form “i.j” */
 const char* primecount_version(void);
 
